/*****************************************************************************
 * File:            test.c
 * Creation Date:   January 06, 2021
 * Description:     Runs several platform alignment tests
 * Compile:         make test-bin
 * Usage:           ./test
 *
 * Copyright (c) 2021, FM10K-Documentation Contributors
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the copyright holders nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#include "fm10k.h"
#include <stdio.h>

#define TEST(have, expected, i) if(have != expected){ printf("[TEST %u] FAIL: " i "\n", ++tests, have, expected); ++testsFailed; }else { printf("[TEST %u] PASS: " i "\n", ++tests, have, expected);}

int main(int argc, char **argv) {
    uint32_t tests = 0;
    uint32_t testsFailed = 0;
    {
        SPI_CTRL s;
        TEST((uint32_t) sizeof(s.fields), (uint32_t) sizeof(s.value), "SPI_CTRL packed misalignment. size struct %u, size value %u");
    }
    {
        SPI_COMMAND_READ_MANUFACTURER_RESULT s;
        TEST((uint32_t) sizeof(s.fields), (uint32_t) sizeof(s.value),
             "SPI_COMMAND_READ_MANUFACTURER_RESULT packed misalignment. size struct %u, size value %u");
    }
    {
        API_SPI_LOCK_STATE s;
        TEST((uint32_t) sizeof(s.fields), (uint32_t) sizeof(s.value),
             "API_SPI_LOCK_STATE packed misalignment. size struct %u, size value %u");
    }

    printf("\nTests run, failed %u/%u\n", testsFailed, tests);
    return testsFailed > 0 ? 1 : 0;
}
